/*****************************************************/
/*          This java file is a part of the          */
/*                                                   */
/*           -  Plouf's Java IRC Client  -           */
/*                                                   */
/*   Copyright (C)  2002 - 2003 Philippe Detournay   */
/*                                                   */
/*         All contacts : theplouf@yahoo.com         */
/*                                                   */
/*  PJIRC is free software; you can redistribute     */
/*  it and/or modify it under the terms of the GNU   */
/*  General Public License as published by the       */
/*  Free Software Foundation; version 2 or later of  */
/*  the License.                                     */
/*                                                   */
/*  PJIRC is distributed in the hope that it will    */
/*  be useful, but WITHOUT ANY WARRANTY; without     */
/*  even the implied warranty of MERCHANTABILITY or  */
/*  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU   */
/*  General Public License for more details.         */
/*                                                   */
/*  You should have received a copy of the GNU       */
/*  General Public License along with PJIRC; if      */
/*  not, write to the Free Software Foundation,      */
/*  Inc., 59 Temple Place, Suite 330, Boston,        */
/*  MA  02111-1307  USA                              */
/*                                                   */
/*****************************************************/

package irc;

import java.util.*;

/**
 * Handles a group of listeners.
 */
public class ListenerGroup
{
  private Hashtable _listeners;

  /**
   * Create a new ListenerGroup.
   */
  public ListenerGroup()
  {
    _listeners=new Hashtable();
  }

  /**
   * Add a listener to the group.
   * @param listener listener to add.
   */
  public synchronized void addListener(Object listener)
  {
    _listeners.put(listener,listener);
  }

  /**
   * Remove a listener from the group.
   * @param listener listener to remove.
   */
  public synchronized void removeListener(Object listener)
  {
    _listeners.remove(listener);
  }

  /**
   * Send an event to all listeners in the group.
   * @param method method to call on each listener.
   * @param params parameters to pass to the called method.
   * @return a result from any called listener.
   */
  public synchronized Object sendEvent(String method,Object[] params)
  {
    Enumeration e=_listeners.elements();
    Object ans=null;
    while(e.hasMoreElements())
    {
      ans=EventDispatcher.dispatchEvent(e.nextElement(),method,params);
    }
    return ans;
  }

  /**
   * Send an event to all listeners in the group, but asynchronously. Any return
   * result is discared.
   * @param method method to call on each listener.
   * @param params parameters to pass to the called method.
   */
  public synchronized void sendEventAsync(String method,Object[] params)
  {
    Enumeration e=_listeners.elements();
    while(e.hasMoreElements())
      EventDispatcher.dispatchEventAsync(e.nextElement(),method,params);
  }

  /**
   * Send an event to all listeners in the group.
   * @param method method to call on each listener.
   * @return a result from any called listener.
   */
  public synchronized Object sendEvent(String method)
  {
    return sendEvent(method,new Object[0]);
  }

  /**
   * Send an event to all listeners in the group.
   * @param method method to call on each listener.
   * @param param1 first parameter to pass to the called method.
   * @return a result from any called listener.
   */
  public synchronized Object sendEvent(String method,Object param1)
  {
    Object[] p={param1};
    return sendEvent(method,p);
  }

  /**
   * Send an event to all listeners in the group.
   * @param method method to call on each listener.
   * @param param1 first parameter to pass to the called method.
   * @param param2 second parameter to pass to the called method.
   * @return a result from any called listener.
   */
  public synchronized Object sendEvent(String method,Object param1,Object param2)
  {
    Object[] p={param1,param2};
    return sendEvent(method,p);
  }

  /**
   * Send an event to all listeners in the group.
   * @param method method to call on each listener.
   * @param param1 first parameter to pass to the called method.
   * @param param2 second parameter to pass to the called method.
   * @param param3 third parameter to pass to the called method.
   * @return a result from any called listener.
   */
  public synchronized Object sendEvent(String method,Object param1,Object param2,Object param3)
  {
    Object[] p={param1,param2,param3};
    return sendEvent(method,p);
  }

}
