/*****************************************************/
/*          This java file is a part of the          */
/*                                                   */
/*           -  Plouf's Java IRC Client  -           */
/*                                                   */
/*   Copyright (C)  2002 - 2003 Philippe Detournay   */
/*                                                   */
/*         All contacts : theplouf@yahoo.com         */
/*                                                   */
/*  PJIRC is free software; you can redistribute     */
/*  it and/or modify it under the terms of the GNU   */
/*  General Public License as published by the       */
/*  Free Software Foundation; version 2 or later of  */
/*  the License.                                     */
/*                                                   */
/*  PJIRC is distributed in the hope that it will    */
/*  be useful, but WITHOUT ANY WARRANTY; without     */
/*  even the implied warranty of MERCHANTABILITY or  */
/*  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU   */
/*  General Public License for more details.         */
/*                                                   */
/*  You should have received a copy of the GNU       */
/*  General Public License along with PJIRC; if      */
/*  not, write to the Free Software Foundation,      */
/*  Inc., 59 Temple Place, Suite 330, Boston,        */
/*  MA  02111-1307  USA                              */
/*                                                   */
/*****************************************************/

package irc;

/**
 * The status.
 */
public class Status extends IRCSource implements ReplyServerListener
{
  private ListenerGroup _listeners;

  /**
   * Create a new Status.
   * @param config global irc configuration.
   * @param s server.
   */
  public Status(IRCConfiguration config,IRCServer s)
  {
    super(config,s);
    s.addReplyServerListener(this);
    _listeners=new ListenerGroup();
    setInterpretor(new StatusInterpretor(config));
  }

  public void release()
  {
    ((IRCServer)_server).removeReplyServerListener(this);
    super.release();
  }

  public String getType()
  {
    return "Status";
  }

  public String getName()
  {
    String res="";
	  if(_ircConfiguration.getB("UseInfo"))
      res=getText(TextProvider.SOURCE_INFO);
		else
      res=getText(TextProvider.SOURCE_STATUS);

    if(getServerName().length()>0)
      res+=" "+getServerName();
    return res;
  }

  public String getServerName()
  {
    return getIRCServer().getServerName();
  }

  public boolean talkable()
  {
    return false;
  }

  public void leave()
  {
    if(!_ircConfiguration.getB("MultiServer")) return;

    //sendString("/quit");
    getIRCServer().leaveStatus(getName());
  }

  /**
   * Get this status nick.
   * @return status nick.
   */
  public String getNick()
  {
    return _server.getNick();
  }

  /**
   * Get this status mode.
   * @return status mode.
   */
  public String getMode()
  {
    return getIRCServer().getMode();
  }

  /**
   * Add listener.
   * @param lis listener to add.
   */
  public void addStatusListener(StatusListener lis)
  {
    _listeners.addListener(lis);
  }

  /**
   * Remove listener.
   * @param lis listener to remove.
   */
  public void removeStatusListener(StatusListener lis)
  {
    _listeners.removeListener(lis);
  }

  /**
   * Notify this status that the nick has changed.
   * @param nick new nick.
   */
  public void nickChanged(String nick)
  {
    _listeners.sendEvent("nickChanged",nick);
  }

  /**
   * Notify this status that the mode has changed.
   * @param mode new mode.
   */
  public void modeChanged(String mode)
  {
    _listeners.sendEvent("modeChanged",mode);
  }

  public void replyReceived(String prefix,String id,String params[])
	{
    if(id.equals("322")) return; //chanlist
    if(_ircConfiguration.getB("UseInfo"))
    {
      int i=new Integer(id).intValue();
      if((i>=300) && (i!=372)) return;
    }
    if(id.equals("301")) //away
	  {
      String toSend=getText(TextProvider.SOURCE_AWAY,params[1])+" :";
      for(int i=2;i<params.length;i++) toSend+=" "+params[i];
      Source src=getIRCServer().getDefaultSource();
      if(src!=null) src.report(toSend);
	  }
	  else if(id.equals("401")) //no such nick/channel
	  {
      Source src=getIRCServer().getDefaultSource();
      String toSend="";
      for(int i=1;i<params.length;i++) toSend+=" "+params[i];
      toSend=toSend.substring(1);
      if(src!=null) src.report(toSend);
	  }
	  else
	  {
      String toSend="";
      for(int i=1;i<params.length;i++) toSend+=" "+params[i];
      toSend=toSend.substring(1);
      report(toSend);
    }
	}
}

