/*****************************************************/
/*          This java file is a part of the          */
/*                                                   */
/*           -  Plouf's Java IRC Client  -           */
/*                                                   */
/*   Copyright (C)  2002 - 2003 Philippe Detournay   */
/*                                                   */
/*         All contacts : theplouf@yahoo.com         */
/*                                                   */
/*  PJIRC is free software; you can redistribute     */
/*  it and/or modify it under the terms of the GNU   */
/*  General Public License as published by the       */
/*  Free Software Foundation; version 2 or later of  */
/*  the License.                                     */
/*                                                   */
/*  PJIRC is distributed in the hope that it will    */
/*  be useful, but WITHOUT ANY WARRANTY; without     */
/*  even the implied warranty of MERCHANTABILITY or  */
/*  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU   */
/*  General Public License for more details.         */
/*                                                   */
/*  You should have received a copy of the GNU       */
/*  General Public License along with PJIRC; if      */
/*  not, write to the Free Software Foundation,      */
/*  Inc., 59 Temple Place, Suite 330, Boston,        */
/*  MA  02111-1307  USA                              */
/*                                                   */
/*****************************************************/

package irc.gui;

import irc.*;
import java.awt.*;
import java.awt.event.*;

/**
 * The style selector.
 */
public class AWTStyleSelector extends Panel implements MouseListener
{
  private IRCConfiguration _ircConfiguration;
  private ColorContext _ct;
  private int _color;
  private boolean _bold;
  private boolean _underline;

  /**
   * Create a new AWTStyleSelector.
   * @param config global irc configuration.
   */
  public AWTStyleSelector(IRCConfiguration config)
  {
    super();
    _ircConfiguration=config;
    _color=1;
    _bold=false;
    _underline=false;
    addMouseListener(this);
    _ct=_ircConfiguration.getDefaultColorContext();
  }

  /**
   * Release this object.
   */
  public void release()
  {
    removeMouseListener(this);
    _ircConfiguration=null;
  }

  /**
   * Set the color context.
   * @param ct color context.
   */
  public void setColorContext(ColorContext ct)
  {
    _ct=ct;
  }

  public void paint(Graphics g)
  {
    update(g);
  }

  private void drawSelect(Graphics g,int i,int j)
  {
    int x=(int)(i*getItemWidth());
    int y=(int)(j*getItemHeight());
    int w=(int)getItemWidth();
    int h=(int)getItemHeight();
    g.setColor(Color.black);
    g.drawRect(x+1,y+1,w-2,h-2);
    g.setColor(Color.white);
    g.drawRect(x,y,w-2,h-2);
  }

  private void drawColor(Graphics g,int i,int j,Color c)
  {
    int x=(int)(i*getItemWidth());
    int y=(int)(j*getItemHeight());
    int w=(int)getItemWidth();
    int h=(int)getItemHeight();
    g.setColor(c);
    g.fillRect(x,y,w,h);
  }

  private void drawBold(Graphics g,int i,int j)
  {
    int x=(int)(i*getItemWidth());
    int y=(int)(j*getItemHeight());
    int w=(int)getItemWidth();
    int h=(int)getItemHeight();
    int tw=g.getFontMetrics().stringWidth("a");
    g.drawString("a",x+(w-tw)/2,y+h-(h-g.getFont().getSize())/2-2);
    g.drawString("a",x+(w-tw)/2+1,y+h-(h-g.getFont().getSize())/2-2);
  }

  private void drawUnderline(Graphics g,int i,int j)
  {
    int x=(int)(i*getItemWidth());
    int y=(int)(j*getItemHeight());
    int w=(int)getItemWidth();
    int h=(int)getItemHeight();
    int tw=g.getFontMetrics().stringWidth("a");
    g.drawString("a",x+(w-tw)/2,y+h-(h-g.getFont().getSize())/2-2);

    g.drawLine(x+w/2-tw/2,y+h-1,x+w/2+tw/2,y+h-1);
  }

  public void update(Graphics g)
  {
    int w=getSize().width;
    int h=getSize().height;

    Image buffer;
    Graphics gra;
    try
    {
      buffer=createImage(w,h);
      gra=buffer.getGraphics();
    }
    catch(Throwable e)
    {
      return;
    }

    Color[] cols=_ircConfiguration.getStyleColors(_ct);
    int c=0;
    for(int y=0;y<2;y++)
    {
      for(int x=1;x<9;x++)
      {
        drawColor(gra,x,y,cols[c]);
        if(c==_color) drawSelect(gra,x,y);
        c++;
      }
    }

    gra.setColor(cols[0]);
    gra.fillRect(0,0,(int)getItemWidth(),h);

    gra.setColor(cols[_color]);
    drawBold(gra,0,0);
    drawUnderline(gra,0,1);

    if(_bold) drawSelect(gra,0,0);
    if(_underline) drawSelect(gra,0,1);


    g.drawImage(buffer,0,0,this);
  }


  public Dimension getPreferredSize()
  {
    return new Dimension(9*10,10);
  }

  private double getItemWidth()
  {
    return getSize().width/9.0;
  }

  private double getItemHeight()
  {
    return getSize().height/2.0;
  }

  /**
   * Get prefix to be used for text styling.
   * @return text style prefix.
   */
  public String getPrefix()
  {
    String pre="";
    if(_color!=1)
    {
      String c=""+_color;
      if(_color<10) c="0"+c;
      pre=pre+(char)3+c;
    }
    if(_bold) pre+=(char)2;
    if(_underline) pre+=(char)31;
    return pre;
  }

  public void mouseClicked(MouseEvent e)
  {
  }

  public void mouseEntered(MouseEvent e)
  {
  }

  public void mouseExited(MouseEvent e)
  {
  }

  public void mousePressed(MouseEvent e)
  {
    int x=(int)(e.getX()/getItemWidth());
    int y=(int)(e.getY()/getItemHeight());
    if(x==0)
    {
      if(y==0) _bold=!_bold;
      if(y==1) _underline=!_underline;
    }
    else
    {
      x--;
      _color=x+y*8;
    }
    repaint();
  }

  public void mouseReleased(MouseEvent e)
  {
  }

}
